pub enum Cursor {
Blob(Vec<u8>),
Integer(i64),
}Expand description
TrailBase supports cursors in a few formats:
- Integers
- Text-encoded UUIDs ([u8; 16])
- Url-safe base64 encoded blobs including UUIDs.
In practice, we should just support integers and generically blobs. In the future way may want to use encrypted cursors, which would also just be arbitrary url-safe base64 encoded bytes.
Variants
Implementations